@@ -7,6 +7,11 @@ Created on 2020/4/21 10:41 PM
 @author: Boris
 @email: boris@bzkj.tech
 """
+import os, sys
+
+current_path = os.getcwd()
+sys.path.insert(0, os.getcwd().replace("/items", ""))
+sys.path.insert(0, os.getcwd().replace("/parsers", ""))
 
 __all__ = [
     "SingleSpider",
@@ -16,11 +21,11 @@ __all__ = [
     "Response",
     "Item",
     "UpdateItem",
-    "ArgumentParser"
+    "ArgumentParser",
 ]
 
 from spider.core.spiders import Spider, BatchSpider, SingleSpider
 from spider.network.request import Request
 from spider.network.response import Response
 from spider.network.item import Item, UpdateItem
-from spider.utils.custom_argparse import ArgumentParser
\ No newline at end of file
+from spider.utils.custom_argparse import ArgumentParser
